@@ -1,7 +1,7 @@
 *=======================================================================
 *
 *   WCSLIB - an implementation of the FITS WCS proposal.
-*   Copyright (C) 1995-2000, Mark Calabretta
+*   Copyright (C) 1995-2001, Mark Calabretta
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Library General Public
@@ -34,7 +34,7 @@
 *   marked with a white dot on a graphical display of the projection
 *   while bad solutions are flagged with a red circle.
 *
-*   $Id: twcs2.f,v 2.12 2000/12/04 05:16:00 mcalabre Exp $
+*   $Id: twcs2.f,v 2.13 2001/09/05 04:34:02 mcalabre Exp $
 *-----------------------------------------------------------------------
 *     Set maximum number of axes (MAXIS) and number of axes (NAXIS).
       INTEGER   M, N
@@ -628,8 +628,11 @@
      *                 (ABS(WORLD(WCS(2))- LAT1).GT.TOL .OR.
      *                  ABS(PIX2(WCS(2))-PIXLAT).GT.TOL)) THEN
                   CALL ID (DOID, PCODE, CEL, LNG1, LAT1, PIXLNG, PIXLAT)
-                  WRITE (6, 30) WORLD(WCS(2)), PIX2(WCS(2))
- 30               FORMAT ('  A: LAT2 =',F20.15,'    J2 =',F20.15)
+                  WRITE (6, 30) WORLD(WCS(1)), WORLD(WCS(2)), PHI,
+     *                          THETA, PIX2(WCS(1)), PIX2(WCS(2))
+ 30               FORMAT ('  A: (LNG2) =',F20.15,'   LAT2  =',F20.15,/,
+     *                    '       PHI  =',F20.15,'  THETA  =',F20.15,/,
+     *                    '       (I2) =',F20.15,'     J2  =',F20.15)
                END IF
             END IF
 
@@ -649,8 +652,11 @@
      *                 (ABS(WORLD(WCS(2))- LAT1).GT.TOL .OR.
      *                  ABS(PIX2(WCS(1))-PIXLNG).GT.TOL)) THEN
                   CALL ID (DOID, PCODE, CEL, LNG1, LAT1, PIXLNG, PIXLAT)
-                  WRITE (6, 40) WORLD(WCS(2)), PIX2(WCS(1))
- 40               FORMAT ('  B: LAT2 =',F20.15,'    I2 =',F20.15)
+                  WRITE (6, 40) WORLD(WCS(1)), WORLD(WCS(2)), PHI,
+     *                          THETA, PIX2(WCS(1)), PIX2(WCS(2))
+ 40               FORMAT ('  B: (LNG2) =',F20.15,'   LAT2  =',F20.15,/,
+     *                    '       PHI  =',F20.15,'  THETA  =',F20.15,/,
+     *                    '        I2  =',F20.15,'    (J2) =',F20.15)
                END IF
             END IF
 
@@ -672,8 +678,11 @@
      *                 (ABS(WORLD(WCS(1))- LNG1).GT.TOL .OR.
      *                  ABS(PIX2(WCS(2))-PIXLAT).GT.TOL)) THEN
                   CALL ID (DOID, PCODE, CEL, LNG1, LAT1, PIXLNG, PIXLAT)
-                  WRITE (6, 50) WORLD(WCS(1)), PIX2(WCS(2))
- 50               FORMAT ('  C: LNG2 =',F20.15,'    J2 =',F20.15)
+                  WRITE (6, 50) WORLD(WCS(1)), WORLD(WCS(2)), PHI,
+     *                          THETA, PIX2(WCS(1)), PIX2(WCS(2))
+ 50               FORMAT ('  C:  LNG2  =',F20.15,'  (LAT2) =',F20.15,/,
+     *                    '       PHI  =',F20.15,'  THETA  =',F20.15,/,
+     *                    '       (I2) =',F20.15,'     J2  =',F20.15)
                END IF
             END IF
 
@@ -693,8 +702,11 @@
      *                 (ABS(WORLD(WCS(1))- LNG1).GT.TOL .OR.
      *                  ABS(PIX2(WCS(1))-PIXLNG).GT.TOL)) THEN
                   CALL ID (DOID, PCODE, CEL, LNG1, LAT1, PIXLNG, PIXLAT)
-                  WRITE (6, 60) WORLD(WCS(1)), PIX2(WCS(1))
- 60               FORMAT ('  D: LNG2 =',F20.15,'    I2 =',F20.15)
+                  WRITE (6, 60) WORLD(WCS(1)), WORLD(WCS(2)), PHI,
+     *                          THETA, PIX2(WCS(1)), PIX2(WCS(2))
+ 60               FORMAT ('  D:  LNG2  =',F20.15,'  (LAT2) =',F20.15,/,
+     *                    '       PHI  =',F20.15,'  THETA  =',F20.15,/,
+     *                    '        I2  =',F20.15,'    (J2) =',F20.15)
                END IF
             END IF
 
@@ -723,9 +735,9 @@
 
          WRITE (6, 10) PCODE, LNG1, LAT1, PHI, THETA, PIXLNG,
      *      PIXLAT
- 10      FORMAT (A3,': LNG1 =',F20.15,'  LAT1 =',F20.15,/,
-     *           '      PHI =',F20.15,' THETA =',F20.15,/,
-     *           '       I1 =',F20.15,'    J1 =',F20.15)
+ 10      FORMAT (/,A3,':  LNG1  =',F20.15,'   LAT1  =',F20.15,/,
+     *             '       PHI  =',F20.15,'  THETA  =',F20.15,/,
+     *             '        I1  =',F20.15,'     J1  =',F20.15)
          DOID = 0
 
          CALL PGSCI (9)
